@@ -1,6 +1,6 @@
 #  This file is part of PyBuilder
 #
-#  Copyright 2011-2013 PyBuilder Team
+#  Copyright 2011-2014 PyBuilder Team
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,6 +13,10 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+"""
+    The PyBuilder cli module.
+    Contains the PyBuilder command-line entrypoint.
+"""
 
 import datetime
 import optparse
@@ -22,7 +26,7 @@ import traceback
 
 from pybuilder import __version__
 from pybuilder.core import Logger
-from pybuilder.errors import PythonbuilderException
+from pybuilder.errors import PybuilderException
 from pybuilder.execution import ExecutionManager
 from pybuilder.reactor import Reactor
 from pybuilder.terminal import (BOLD, BROWN, RED, GREEN, bold, styled_text,
@@ -33,7 +37,7 @@ from pybuilder.utils import format_timestamp
 PROPERTY_OVERRIDE_PATTERN = re.compile(r'^[a-zA-Z0-9_]+=.*')
 
 
-class CommandLineUsageException(PythonbuilderException):
+class CommandLineUsageException(PybuilderException):
 
     def __init__(self, usage, message):
         super(CommandLineUsageException, self).__init__(message)
@@ -291,7 +295,7 @@ def main(*args):
 
     if not options.very_quiet:
         print_styled_text_line(
-            "PYBUILDER Version {0}".format(__version__), options, BOLD)
+            "PyBuilder version {0}".format(__version__), options, BOLD)
         print_text_line("Build started at %s" % format_timestamp(start))
         draw_line()
 
@@ -313,7 +317,7 @@ def main(*args):
                 environments=options.environments, tasks=arguments)
 
         except KeyboardInterrupt:
-            raise PythonbuilderException("Build aborted")
+            raise PybuilderException("Build aborted")
 
     except Exception as e:
         failure_message = str(e)
