@@ -1,6 +1,6 @@
 #  This file is part of PyBuilder
 #
-#  Copyright 2011-2013 PyBuilder Team
+#  Copyright 2011-2014 PyBuilder Team
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,6 +13,11 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+"""
+    The PyBuilder reactor module.
+    Operates a build process by instrumenting an ExecutionManager from the
+    execution module.
+"""
 
 import imp
 import os.path
@@ -22,7 +27,7 @@ from pybuilder.core import (TASK_ATTRIBUTE, DEPENDS_ATTRIBUTE,
                             BEFORE_ATTRIBUTE, INITIALIZER_ATTRIBUTE,
                             ACTION_ATTRIBUTE, ONLY_ONCE_ATTRIBUTE,
                             Project, NAME_ATTRIBUTE, ENVIRONMENTS_ATTRIBUTE)
-from pybuilder.errors import PythonbuilderException, ProjectValidationFailedException
+from pybuilder.errors import PybuilderException, ProjectValidationFailedException
 from pybuilder.pluginloader import (BuiltinPluginLoader,
                                     DispatchingPluginLoader,
                                     ThirdPartyPluginLoader)
@@ -121,7 +126,7 @@ class Reactor(object):
             if self.project.default_task:
                 tasks += as_list(self.project.default_task)
             else:
-                raise PythonbuilderException("No default task given.")
+                raise PybuilderException("No default task given.")
 
         execution_plan = self.execution_manager.build_execution_plan(tasks)
         self.logger.debug("Execution plan is %s", ", ".join(
@@ -230,30 +235,30 @@ class Reactor(object):
         try:
             return imp.load_source("build", project_descriptor)
         except ImportError as e:
-            raise PythonbuilderException(
+            raise PybuilderException(
                 "Error importing project descriptor %s: %s" % (project_descriptor, e))
 
     def verify_project_directory(self, project_directory, project_descriptor):
         project_directory = os.path.abspath(project_directory)
 
         if not os.path.exists(project_directory):
-            raise PythonbuilderException(
+            raise PybuilderException(
                 "Project directory does not exist: %s", project_directory)
 
         if not os.path.isdir(project_directory):
-            raise PythonbuilderException(
+            raise PybuilderException(
                 "Project directory is not a directory: %s", project_directory)
 
         project_descriptor_full_path = os.path.join(
             project_directory, project_descriptor)
 
         if not os.path.exists(project_descriptor_full_path):
-            raise PythonbuilderException(
+            raise PybuilderException(
                 "Project directory does not contain descriptor file: %s",
                 project_descriptor_full_path)
 
         if not os.path.isfile(project_descriptor_full_path):
-            raise PythonbuilderException(
+            raise PybuilderException(
                 "Project descriptor is not a file: %s", project_descriptor_full_path)
 
         return project_directory, project_descriptor_full_path
