@@ -1,18 +1,22 @@
-#   This file is part of PyBuilder
+#  This file is part of PyBuilder
 #
-#   Copyright 2011-2013 PyBuilder Team
+#  Copyright 2011-2014 PyBuilder Team
 #
-#   Licensed under the Apache License, Version 2.0 (the "License");
-#   you may not use this file except in compliance with the License.
-#   You may obtain a copy of the License at
+#  Licensed under the Apache License, Version 2.0(the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
 #
 #      http://www.apache.org/licenses/LICENSE-2.0
 #
-#   Unless required by applicable law or agreed to in writing, software
-#   distributed under the License is distributed on an "AS IS" BASIS,
-#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#   See the License for the specific language governing permissions and
-#   limitations under the License.
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+"""
+    The PyBuilder utils module.
+    Provides generic utilities that can be used by plugins.
+"""
 
 import json
 import os
@@ -21,7 +25,7 @@ import subprocess
 import tempfile
 import time
 
-from pybuilder.errors import MissingPrerequisiteException, PythonbuilderException
+from pybuilder.errors import MissingPrerequisiteException, PybuilderException
 
 
 def render_report(report_dict):
@@ -73,15 +77,26 @@ def as_list(*whatever):
     return result
 
 
+def remove_leading_slash_or_dot_from_path(path):
+    if path.startswith('/') or path.startswith('.'):
+            return path[1:]
+    return path
+
+
+def remove_python_source_suffix(file_name):
+    return file_name[0:-len(".py")]
+
+
 def discover_modules(source_path, suffix=".py"):
     result = []
-    for module in discover_files(source_path, suffix):
-        module = module.replace(source_path, "")
-        module = module.replace(os.sep, ".")
-        module = module[1:-3]
-        if module.endswith(".__init__"):
-            module = module.replace(".__init__", "")
-        result.append(module)
+    for module_file_path in discover_files(source_path, suffix):
+        relative_module_file_path = module_file_path.replace(source_path, "")
+        relative_module_file_path = relative_module_file_path.replace(os.sep, ".")
+        module_file = remove_leading_slash_or_dot_from_path(relative_module_file_path)
+        module_name = remove_python_source_suffix(module_file)
+        if module_name.endswith(".__init__"):
+            module_name = module_name.replace(".__init__", "")
+        result.append(module_name)
     return result
 
 
@@ -145,7 +160,7 @@ class Timer(object):
 
     def get_millis(self):
         if self.end_time is None:
-            raise PythonbuilderException("Timer is running.")
+            raise PybuilderException("Timer is running.")
         return int((self.end_time - self.start_time) * 1000)
 
 
@@ -180,13 +195,13 @@ class GlobExpression(object):
 def mkdir(directory):
     """
     Tries to create the directory denoted by the given name. If it exists and is a directory, nothing will be created
-    and no error is raised. If it exists as a file a PythonbuilderException is raised. Otherwise the directory incl.
+    and no error is raised. If it exists as a file a PybuilderException is raised. Otherwise the directory incl.
     all parents is created.
     """
 
     if os.path.exists(directory):
         if os.path.isfile(directory):
             message = "Unable to created directory '%s': A file with that name already exists"
-            raise PythonbuilderException(message, directory)
+            raise PybuilderException(message, directory)
         return
     os.makedirs(directory)
